#!/bin/bash -e
#
# splash.sh - script to paint progress bar during
# system startup/shutdown. This script is solely run
# by the init scripts (shell function rc_splash)
#
# (w) 2002-2003 Stefan Reinauer, <stepan@suse.de>
# 2003 Florent Villard, <warly@mandrakesoft.com>
# It's licensed under GPL, of course.
#
# this script expects the following environment variables:
#  splash_nbservices = number of start/stop scripts to be executed for runlevel change
#  splash_progress = number of currently executed start/stop script
#  runlevel = runlevel to be reached.

TEXTDOMAIN=bootsplash
TEXTDOMAINDIR=/etc/locale 
LOCPATH=/etc/locale

. /etc/init.d/functions

SourceIfNotEmpty /etc/init.d/functions-bootsplash

_procsplash="`cat $splash_proc 2>/dev/null`"

# assertions
test -r $splash_proc || exit 0
grep -iwqs off "$splash_proc" && exit 0

splash_res=`fbresolution`
if [ -f /etc/sysconfig/bootsplash ]; then
    . /etc/sysconfig/bootsplash
    splash_theme=$THEME
    tmpval=$LOGO_CONSOLE
    if [ -f /etc/bootsplash/themes/$splash_theme/config/bootsplash-$splash_res.cfg ]; then
        function mnganim() { true; }
        function trigger() { true; }
        function box() { true; }
        . /etc/bootsplash/themes/$splash_theme/config/bootsplash-$splash_res.cfg
    fi
    if [ "$tmpval" != "theme" ];then
        LOGO_CONSOLE=$tmpval
    fi
fi

_shutdown="no"
_silent="no"
#grep -q silent /proc/cmdline && grep -q silent $splash_proc && _silent="yes"
grep -q silent /proc/cmdline && _silent="yes"
test "$runlevel" == "6" -o "$runlevel" == "0" && _shutdown="yes"

if [ "$1" == "verbose" ]; then
    echo 'verbose' > $splash_proc
fi

if [ "$1" == "stop" -a $_shutdown == "no" ]; then
    if is_no "$LOGO_CONSOLE"; then                                                        
	if [[ -e $splash_proc ]];then
	    echo 0 > $splash_proc
	    exit 0
	fi 
    else 
	if [[ $LOGO_CONSOLE == vt ]]; then
	    for i in 0 1 2 3 4 5
	    do
		if [[ -f /etc/bootsplash/themes/$splash_theme/config/vt$i-$splash_res.cfg ]]; then
		    if [ "$progress_enable" == "1" ]; then
			/sbin/splash -s -u $i /etc/bootsplash/themes/$splash_theme/config/vt$i-$splash_res.cfg
		    else
		        splash_trigger "rlchange 0"
		    fi
		fi
	    done
	fi
    fi
fi

#test -z "$splash_progress" -a -z "$splash_nbservices" && exit 0
#grep -vq "splash=silent" /proc/cmdline && exit 0 

if [ "$previous" == "3" -a "$previous" == "5" ] ; then
    exit 0
fi
if [ "$runlevel" == "5" -a "$runlevel" == "3" ] ; then
    exit 0
fi

# acquire data
# 
num=$(( $splash_nbservices + 1))

# Initialize
if [ "$splash_progress" == 1 -o "$1" == "start" ]; then
    if test "$_shutdown" == "yes"; then 
        [ -f $splash_theme_file ] && splash_trigger "rlchange 0"
        timeout 1 chvt 1
	[ $? == 124 ]&&(chvt 1)&
else 
	if [ "$_silent" == "yes" ]; then
	    if [ -f $splash_theme_file ]; then
		if [ "$progress_enable" == "1" ]; then
		    [ "$splash_progress" != "1" ] && \
			echo "show $(( 65534 * ( $splash_progress + 1 ) / $num ))" > /proc/splash
		else
		    splash_trigger "silent"
		fi
	    fi
	fi
    fi
fi

# Paint progressbar..
if [ "$progress_enable" == "1" ]; then
    echo "show $(( 65534 * ( $splash_progress + 1) / $num ))" > /proc/splash
else
    if [ "$splash_progress" == "$splash_nbservices" ]; then
	splash_trigger "rlreached 5"
    fi
fi
